==> zizmor-1.10.0.tar.gz: zizmor-1.10.0/crates/README.md <==
# crates

This directory contains `zizmor`'s various crates.

See the table and each subdirectory for more details on each crate.
| Crate | Version | Documentation | Description |
|-------|---------|---------------|-------------|
| [`zizmor`][zizmor-dir] | [![Crates.io](https://img.shields.io/crates/v/zizmor)][zizmor-crates] | [![docs.zizmor.sh](https://img.shields.io/badge/zizmor-docs.zizmor.sh-blue)][zizmor-docs] | The `zizmor` CLI and core auditing functionality. |
| [`yamlpath`][yamlpath-dir] | [![Crates.io](https://img.shields.io/crates/v/yamlpath)][yamlpath-crates] | [![docs.rs](https://img.shields.io/docsrs/yamlpath)][yamlpath-docs] | Format-preserving YAML feature extraction. |
| [`github-actions-models`][github-actions-models-dir] | [![Crates.io](https://img.shields.io/crates/v/github-actions-models)][github-actions-models-crates] | [![docs.rs](https://img.shields.io/docsrs/github-actions-models)][github-actions-models-docs] | Unofficial, high-quality data models for GitHub Actions workflows, actions, and related components. |
| [`github-actions-expressions`][github-actions-expressions-dir] | [![Crates.io](https://img.shields.io/crates/v/github-actions-expressions)][github-actions-expressions-crates] | [![docs.rs](https://img.shields.io/docsrs/github-actions-expressions)][github-actions-expressions-docs] | Parser and library for GitHub Actions expressions. |

[zizmor-dir]: ./zizmor
[zizmor-crates]: https://crates.io/crates/zizmor
[zizmor-docs]: https://docs.zizmor.sh/

[yamlpath-dir]: ./yamlpath
[yamlpath-crates]: https://crates.io/crates/yamlpath
[yamlpath-docs]: https://docs.rs/yamlpath

[github-actions-models-dir]: ./github-actions-models
[github-actions-models-crates]: https://crates.io/crates/github-actions-models
[github-actions-models-docs]: https://docs.rs/github-actions-models

[github-actions-expressions-dir]: ./github-actions-expressions
[github-actions-expressions-crates]: https://crates.io/crates/github-actions-expressions
[github-actions-expressions-docs]: https://docs.rs/github-actions-expressions

==> zizmor-1.14.2.tar.gz: zizmor-1.14.2/crates/README.md <==
# crates

This directory contains `zizmor`'s various crates.

See the table and each subdirectory for more details on each crate.
| Crate | Version | Documentation | Description |
|-------|---------|---------------|-------------|
| [`zizmor`][zizmor-dir] | [![Crates.io](https://img.shields.io/crates/v/zizmor)][zizmor-crates] | [![docs.zizmor.sh](https://img.shields.io/badge/zizmor-docs.zizmor.sh-blue)][zizmor-docs] | The `zizmor` CLI and core auditing functionality. |
| [`subfeature`][subfeature-dir] | [![Crates.io](https://img.shields.io/crates/v/subfeature)][subfeature-crates] | [![docs.rs](https://img.shields.io/docsrs/subfeature)][subfeature-docs] | Subfeature handling APIs. |
| [`yamlpath`][yamlpath-dir] | [![Crates.io](https://img.shields.io/crates/v/yamlpath)][yamlpath-crates] | [![docs.rs](https://img.shields.io/docsrs/yamlpath)][yamlpath-docs] | Format-preserving YAML feature extraction. |
| [`yamlpatch`][yamlpath-dir] | [![Crates.io](https://img.shields.io/crates/v/yamlpatch)][yamlpath-crates] | [![docs.rs](https://img.shields.io/docsrs/yamlpatch)][yamlpath-docs] | Comment and format-preserving YAML patch operations. |
| [`github-actions-models`][github-actions-models-dir] | [![Crates.io](https://img.shields.io/crates/v/github-actions-models)][github-actions-models-crates] | [![docs.rs](https://img.shields.io/docsrs/github-actions-models)][github-actions-models-docs] | Unofficial, high-quality data models for GitHub Actions workflows, actions, and related components. |
| [`github-actions-expressions`][github-actions-expressions-dir] | [![Crates.io](https://img.shields.io/crates/v/github-actions-expressions)][github-actions-expressions-crates] | [![docs.rs](https://img.shields.io/docsrs/github-actions-expressions)][github-actions-expressions-docs] | Parser and library for GitHub Actions expressions. |

[zizmor-dir]: ./zizmor
[zizmor-crates]: https://crates.io/crates/zizmor
[zizmor-docs]: https://docs.zizmor.sh/

[subfeature-dir]: ./subfeature
[subfeature-crates]: https://crates.io/crates/subfeature
[subfeature-docs]: https://docs.rs/subfeature

[yamlpath-dir]: ./yamlpath
[yamlpath-crates]: https://crates.io/crates/yamlpath
[yamlpath-docs]: https://docs.rs/yamlpath

[yamlpatch-dir]: ./yamlpatch
[yamlpatch-crates]: https://crates.io/crates/yamlpatch
[yamlpatch-docs]: https://docs.rs/yamlpatch

[github-actions-models-dir]: ./github-actions-models
[github-actions-models-crates]: https://crates.io/crates/github-actions-models
[github-actions-models-docs]: https://docs.rs/github-actions-models

[github-actions-expressions-dir]: ./github-actions-expressions
[github-actions-expressions-crates]: https://crates.io/crates/github-actions-expressions
[github-actions-expressions-docs]: https://docs.rs/github-actions-expressions
